@@ -709,24 +709,24 @@ class SerializationTest(unittest.TestCase):
         a = model.About(test_file)
         assert [] == a.errors
 
-        expected = u'''about_resource: .
+        expected = '''about_resource: .
 name: AboutCode
 version: 0.11.0
 copyright: Copyright (c) 2013-2014 nexB Inc.
 license_expression: apache-2.0
 author:
-    - Jillian Daguil
-    - Chin Yeung Li
-    - Philippe Ombredanne
-    - Thomas Druez
-description: |-
-    AboutCode is a tool
-    to process ABOUT files.
-    An ABOUT file is a file.
+  - Jillian Daguil
+  - Chin Yeung Li
+  - Philippe Ombredanne
+  - Thomas Druez
+description: |
+  AboutCode is a tool
+  to process ABOUT files.
+  An ABOUT file is a file.
 homepage_url: http://dejacode.org
 licenses:
-    -   file: apache-2.0.LICENSE
-        key: apache-2.0
+  - key: apache-2.0
+    file: apache-2.0.LICENSE
 notice_file: NOTICE
 owner: nexB Inc.
 vcs_repository: https://github.com/dejacode/about-code-tool.git
